# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Global.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import GroupChangeMemberRights_pb2 as GroupChangeMemberRights__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Global.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x0cGlobal.proto\x12\x05proto\x1a\x1dGroupChangeMemberRights.proto\"/\n\x13RoomMessageLocation\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lon\x18\x02 \x01(\x01\"\xc4\x04\n\x0eRoomMessageLog\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.proto.RoomMessageLog.Type\x12\x33\n\nextra_type\x18\x02 \x01(\x0e\x32\x1f.proto.RoomMessageLog.ExtraType\x12\x35\n\x0btarget_user\x18\x03 \x01(\x0b\x32 .proto.RoomMessageLog.TargetUser\x1a\x18\n\nTargetUser\x12\n\n\x02id\x18\x01 \x01(\x04\"\xd5\x02\n\x04Type\x12\x0f\n\x0bUSER_JOINED\x10\x00\x12\x10\n\x0cUSER_DELETED\x10\x01\x12\x10\n\x0cROOM_CREATED\x10\x02\x12\x10\n\x0cMEMBER_ADDED\x10\x03\x12\x11\n\rMEMBER_KICKED\x10\x04\x12\x0f\n\x0bMEMBER_LEFT\x10\x05\x12\x1c\n\x18ROOM_CONVERTED_TO_PUBLIC\x10\x06\x12\x1d\n\x19ROOM_CONVERTED_TO_PRIVATE\x10\x07\x12 \n\x1cMEMBER_JOINED_BY_INVITE_LINK\x10\x08\x12\x10\n\x0cROOM_DELETED\x10\t\x12\x15\n\x11MISSED_VOICE_CALL\x10\n\x12\x15\n\x11MISSED_VIDEO_CALL\x10\x0b\x12\x17\n\x13MISSED_SCREEN_SHARE\x10\x0c\x12\x16\n\x12MISSED_SECRET_CHAT\x10\r\x12\x12\n\x0ePINNED_MESSAGE\x10\x0e\"*\n\tExtraType\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x0f\n\x0bTARGET_USER\x10\x01\"k\n\x12RoomMessageContact\x12\x12\n\nfirst_name\x18\x01 \x01(\t\x12\x11\n\tlast_name\x18\x02 \x01(\t\x12\x10\n\x08nickname\x18\x03 \x01(\t\x12\r\n\x05phone\x18\x04 \x03(\t\x12\r\n\x05\x65mail\x18\x05 \x03(\t\"\x80\r\n\x11RoomMessageWallet\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.proto.RoomMessageWallet.Type\x12>\n\x0emoney_transfer\x18\x02 \x01(\x0b\x32&.proto.RoomMessageWallet.MoneyTransfer\x12\x39\n\x0c\x63\x61rd_to_card\x18\x03 \x01(\x0b\x32#.proto.RoomMessageWallet.CardToCard\x12-\n\x05topup\x18\x04 \x01(\x0b\x32\x1e.proto.RoomMessageWallet.Topup\x12+\n\x04\x62ill\x18\x05 \x01(\x0b\x32\x1d.proto.RoomMessageWallet.Bill\x1a\xc0\x01\n\rMoneyTransfer\x12\x14\n\x0c\x66rom_user_id\x18\x01 \x01(\x04\x12\x12\n\nto_user_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\x12\x14\n\x0ctrace_number\x18\x04 \x01(\x03\x12\x16\n\x0einvoice_number\x18\x05 \x01(\x03\x12\x10\n\x08pay_time\x18\x06 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x13\n\x0b\x63\x61rd_number\x18\x08 \x01(\t\x12\x0b\n\x03rrn\x18\t \x01(\x03\x1a\xa5\x02\n\nCardToCard\x12\x14\n\x0c\x66rom_user_id\x18\x01 \x01(\x04\x12\x12\n\nto_user_id\x18\x02 \x01(\x04\x12\x10\n\x08order_id\x18\x03 \x01(\x04\x12\r\n\x05token\x18\x04 \x01(\t\x12\x0e\n\x06\x61mount\x18\x05 \x01(\x04\x12\x1a\n\x12source_card_number\x18\x06 \x01(\t\x12\x18\n\x10\x64\x65st_card_number\x18\x07 \x01(\t\x12\x14\n\x0crequest_time\x18\x08 \x01(\r\x12\x0b\n\x03rrn\x18\t \x01(\t\x12\x14\n\x0ctrace_number\x18\n \x01(\t\x12\x10\n\x08\x62\x61nkName\x18\x0b \x01(\t\x12\x14\n\x0c\x64\x65stBankName\x18\x0c \x01(\t\x12\x15\n\rcardOwnerName\x18\r \x01(\t\x12\x0e\n\x06status\x18\x0e \x01(\x08\x1a\xef\x03\n\x05Topup\x12\x14\n\x0c\x66rom_user_id\x18\x01 \x01(\x04\x12\x10\n\x08order_id\x18\x02 \x01(\x04\x12\x10\n\x08my_token\x18\x03 \x01(\t\x12\r\n\x05token\x18\x04 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x05 \x01(\x04\x12\x1f\n\x17requester_mobile_number\x18\x06 \x01(\t\x12\x1c\n\x14\x63harge_mobile_number\x18\x07 \x01(\t\x12\x37\n\ntopup_type\x18\x08 \x01(\x0e\x32#.proto.RoomMessageWallet.Topup.Type\x12\x13\n\x0b\x63\x61rd_number\x18\t \x01(\t\x12\x15\n\rmerchant_name\x18\n \x01(\t\x12\x13\n\x0bterminal_no\x18\x0b \x01(\x04\x12\x0b\n\x03rrn\x18\x0c \x01(\x04\x12\x14\n\x0ctrace_number\x18\r \x01(\x04\x12\x14\n\x0crequest_time\x18\x0e \x01(\r\x12\x0e\n\x06status\x18\x0f \x01(\x08\x12\x1a\n\x12status_description\x18\x10 \x01(\t\"o\n\x04Type\x12\x14\n\x10IRANCELL_PREPAID\x10\x00\x12\x10\n\x0cIRANCELL_WOW\x10\x01\x12\x12\n\x0eIRANCELL_WIMAX\x10\x02\x12\x15\n\x11IRANCELL_POSTPAID\x10\x03\x12\x07\n\x03MCI\x10\x04\x12\x0b\n\x07RIGHTEL\x10\x05\x1a\xb9\x02\n\x04\x42ill\x12\x14\n\x0c\x66rom_user_id\x18\x01 \x01(\x04\x12\x10\n\x08order_id\x18\x02 \x01(\x04\x12\x10\n\x08my_token\x18\x03 \x01(\t\x12\r\n\x05token\x18\x04 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x05 \x01(\x04\x12\x0e\n\x06pay_id\x18\x06 \x01(\t\x12\x0f\n\x07\x62ill_id\x18\x07 \x01(\t\x12\x11\n\tbill_type\x18\x08 \x01(\t\x12\x13\n\x0b\x63\x61rd_number\x18\t \x01(\t\x12\x15\n\rmerchant_name\x18\n \x01(\t\x12\x13\n\x0bterminal_no\x18\x0b \x01(\x04\x12\x0b\n\x03rrn\x18\x0c \x01(\x04\x12\x14\n\x0ctrace_number\x18\r \x01(\x04\x12\x14\n\x0crequest_time\x18\x0e \x01(\r\x12\x0e\n\x06status\x18\x0f \x01(\x08\x12\x1a\n\x12status_description\x18\x10 \x01(\t\"N\n\x04Type\x12\x12\n\x0eMONEY_TRANSFER\x10\x00\x12\x0b\n\x07PAYMENT\x10\x01\x12\x10\n\x0c\x43\x41RD_TO_CARD\x10\x02\x12\t\n\x05TOPUP\x10\x03\x12\x08\n\x04\x42ILL\x10\x04\"=\n\x16RoomMessageForwardFrom\x12\x0f\n\x07room_id\x18\x01 \x01(\x04\x12\x12\n\nmessage_id\x18\x02 \x01(\x04\"\xfc\x03\n\x0eRegisteredUser\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\x04\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x06 \x01(\t\x12\x10\n\x08initials\x18\x07 \x01(\t\x12\r\n\x05\x63olor\x18\x08 \x01(\t\x12,\n\x06status\x18\t \x01(\x0e\x32\x1c.proto.RegisteredUser.Status\x12\x11\n\tlast_seen\x18\n \x01(\r\x12\x14\n\x0c\x61vatar_count\x18\x0b \x01(\r\x12\x1d\n\x06\x61vatar\x18\x0c \x01(\x0b\x32\r.proto.Avatar\x12\x0e\n\x06mutual\x18\r \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x0e \x01(\x08\x12\x10\n\x08\x63\x61\x63he_id\x18\x0f \x01(\t\x12\x0b\n\x03\x62io\x18\x10 \x01(\t\x12\x10\n\x08verified\x18\x11 \x01(\x08\x12\x0b\n\x03\x62ot\x18\x12 \x01(\x08\"\x89\x01\n\x06Status\x12\x11\n\rLONG_TIME_AGO\x10\x00\x12\x0e\n\nLAST_MONTH\x10\x01\x12\r\n\tLAST_WEEK\x10\x02\x12\n\n\x06ONLINE\x10\x03\x12\x0b\n\x07\x45XACTLY\x10\x04\x12\x0c\n\x08RECENTLY\x10\x05\x12\x0b\n\x07SUPPORT\x10\x06\x12\x19\n\x15SERVICE_NOTIFICATIONS\x10\x07\"/\n\x06\x41vatar\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x19\n\x04\x66ile\x18\x02 \x01(\x0b\x32\x0b.proto.File\"\xe9\x08\n\x0bRoomMessage\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x17\n\x0fmessage_version\x18\x02 \x01(\x04\x12(\n\x06status\x18\x03 \x01(\x0e\x32\x18.proto.RoomMessageStatus\x12\x16\n\x0estatus_version\x18\x04 \x01(\x04\x12,\n\x0cmessage_type\x18\x05 \x01(\x0e\x32\x16.proto.RoomMessageType\x12\x0f\n\x07message\x18\x06 \x01(\t\x12\x1f\n\nattachment\x18\x07 \x01(\x0b\x32\x0b.proto.File\x12)\n\x06\x61uthor\x18\x08 \x01(\x0b\x32\x19.proto.RoomMessage.Author\x12,\n\x08location\x18\t \x01(\x0b\x32\x1a.proto.RoomMessageLocation\x12\"\n\x03log\x18\n \x01(\x0b\x32\x15.proto.RoomMessageLog\x12*\n\x07\x63ontact\x18\x0b \x01(\x0b\x32\x19.proto.RoomMessageContact\x12(\n\x06wallet\x18\x16 \x01(\x0b\x32\x18.proto.RoomMessageWallet\x12\x0e\n\x06\x65\x64ited\x18\x0c \x01(\x08\x12\x13\n\x0b\x63reate_time\x18\r \x01(\r\x12\x13\n\x0bupdate_time\x18\x0e \x01(\r\x12\x0f\n\x07\x64\x65leted\x18\x0f \x01(\x08\x12(\n\x0c\x66orward_from\x18\x10 \x01(\x0b\x32\x12.proto.RoomMessage\x12$\n\x08reply_to\x18\x11 \x01(\x0b\x32\x12.proto.RoomMessage\x12\x1b\n\x13previous_message_id\x18\x12 \x01(\x04\x12\x11\n\trandom_id\x18\x15 \x01(\x04\x12\x17\n\x0f\x61\x64\x64itional_type\x18\x17 \x01(\r\x12\x17\n\x0f\x61\x64\x64itional_data\x18\x18 \x01(\t\x12\x30\n\nextra_type\x18\x13 \x01(\x0e\x32\x1c.proto.RoomMessage.ExtraType\x12\x36\n\rchannel_extra\x18\x14 \x01(\x0b\x32\x1f.proto.RoomMessage.ChannelExtra\x1a\xb6\x01\n\x06\x41uthor\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12,\n\x04user\x18\x02 \x01(\x0b\x32\x1e.proto.RoomMessage.Author.User\x12,\n\x04room\x18\x03 \x01(\x0b\x32\x1e.proto.RoomMessage.Author.Room\x1a)\n\x04User\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12\x10\n\x08\x63\x61\x63he_id\x18\x02 \x01(\t\x1a\x17\n\x04Room\x12\x0f\n\x07room_id\x18\x01 \x01(\x04\x1aj\n\x0c\x43hannelExtra\x12\x11\n\tsignature\x18\x01 \x01(\t\x12\x13\n\x0bviews_label\x18\x02 \x01(\t\x12\x17\n\x0fthumbs_up_label\x18\x03 \x01(\t\x12\x19\n\x11thumbs_down_label\x18\x04 \x01(\t\",\n\tExtraType\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x11\n\rCHANNEL_EXTRA\x10\x01\"B\n\tRoomDraft\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08reply_to\x18\x02 \x01(\x04\x12\x12\n\ndraft_time\x18\x03 \x01(\r\"\xf9\x04\n\x04Room\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x1e\n\x04type\x18\x02 \x01(\x0e\x32\x10.proto.Room.Type\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08initials\x18\x04 \x01(\t\x12\r\n\x05\x63olor\x18\x05 \x01(\t\x12\x14\n\x0cunread_count\x18\x06 \x01(\r\x12(\n\x0clast_message\x18\x07 \x01(\x0b\x32\x12.proto.RoomMessage\x12\x11\n\tread_only\x18\x08 \x01(\x08\x12\x16\n\x0eis_participant\x18\t \x01(\x08\x12\x1f\n\x05\x64raft\x18\n \x01(\x0b\x32\x10.proto.RoomDraft\x12\x30\n\x14\x66irst_unread_message\x18\x0e \x01(\x0b\x32\x12.proto.RoomMessage\x12\"\n\troom_mute\x18\x0f \x01(\x0e\x32\x0f.proto.RoomMute\x12\x0e\n\x06pin_id\x18\x10 \x01(\x04\x12*\n\x0epinned_message\x18\x11 \x01(\x0b\x32\x12.proto.RoomMessage\x12\x10\n\x08priority\x18\x12 \x01(\r\x12(\n\x0f\x63hat_room_extra\x18\x0b \x01(\x0b\x32\x0f.proto.ChatRoom\x12*\n\x10group_room_extra\x18\x0c \x01(\x0b\x32\x10.proto.GroupRoom\x12.\n\x12\x63hannel_room_extra\x18\r \x01(\x0b\x32\x12.proto.ChannelRoom\x12\x0e\n\x06\x61pp_id\x18\x13 \x01(\r\x12%\n\npermission\x18\x14 \x01(\x0b\x32\x11.proto.RoomAccess\"(\n\x04Type\x12\x08\n\x04\x43HAT\x10\x00\x12\t\n\x05GROUP\x10\x01\x12\x0b\n\x07\x43HANNEL\x10\x02\"/\n\x08\x43hatRoom\x12#\n\x04peer\x18\x01 \x01(\x0b\x32\x15.proto.RegisteredUser\"\x93\x05\n\tGroupRoom\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.proto.GroupRoom.Type\x12#\n\x04role\x18\x02 \x01(\x0e\x32\x15.proto.GroupRoom.Role\x12\x1a\n\x12participants_count\x18\x03 \x01(\r\x12 \n\x18participants_count_label\x18\x04 \x01(\t\x12 \n\x18participants_count_limit\x18\x05 \x01(\r\x12&\n\x1eparticipants_count_limit_label\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x14\n\x0c\x61vatar_count\x18\x08 \x01(\r\x12\x1d\n\x06\x61vatar\x18\t \x01(\x0b\x32\r.proto.Avatar\x12\x34\n\rprivate_extra\x18\n \x01(\x0b\x32\x1d.proto.GroupRoom.PrivateExtra\x12\x32\n\x0cpublic_extra\x18\x0b \x01(\x0b\x32\x1c.proto.GroupRoom.PublicExtra\x12@\n\x0broom_rights\x18\x0c \x01(\x0b\x32+.proto.GroupChangeMemberRights.MemberRights\x1a\x39\n\x0cPrivateExtra\x12\x13\n\x0binvite_link\x18\x01 \x01(\t\x12\x14\n\x0cinvite_token\x18\x02 \x01(\t\x1a\x1f\n\x0bPublicExtra\x12\x10\n\x08username\x18\x01 \x01(\t\")\n\x04Type\x12\x10\n\x0cPRIVATE_ROOM\x10\x00\x12\x0f\n\x0bPUBLIC_ROOM\x10\x01\"7\n\x04Role\x12\n\n\x06MEMBER\x10\x00\x12\r\n\tMODERATOR\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\t\n\x05OWNER\x10\x03\"\xe0\x04\n\x0b\x43hannelRoom\x12%\n\x04type\x18\x01 \x01(\x0e\x32\x17.proto.ChannelRoom.Type\x12%\n\x04role\x18\x02 \x01(\x0e\x32\x17.proto.ChannelRoom.Role\x12\x1a\n\x12participants_count\x18\x03 \x01(\r\x12 \n\x18participants_count_label\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0c\x61vatar_count\x18\x06 \x01(\r\x12\x1d\n\x06\x61vatar\x18\x07 \x01(\x0b\x32\r.proto.Avatar\x12\x36\n\rprivate_extra\x18\x08 \x01(\x0b\x32\x1f.proto.ChannelRoom.PrivateExtra\x12\x34\n\x0cpublic_extra\x18\t \x01(\x0b\x32\x1e.proto.ChannelRoom.PublicExtra\x12\x11\n\tsignature\x18\n \x01(\x08\x12\x0f\n\x07seen_id\x18\x0b \x01(\x04\x12\x10\n\x08verified\x18\x0c \x01(\x08\x12\x17\n\x0freaction_status\x18\r \x01(\x08\x1a\x39\n\x0cPrivateExtra\x12\x13\n\x0binvite_link\x18\x01 \x01(\t\x12\x14\n\x0cinvite_token\x18\x02 \x01(\t\x1a\x1f\n\x0bPublicExtra\x12\x10\n\x08username\x18\x01 \x01(\t\")\n\x04Type\x12\x10\n\x0cPRIVATE_ROOM\x10\x00\x12\x0f\n\x0bPUBLIC_ROOM\x10\x01\"7\n\x04Role\x12\n\n\x06MEMBER\x10\x00\x12\r\n\tMODERATOR\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\t\n\x05OWNER\x10\x03\"f\n\tThumbnail\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x10\n\x08\x63\x61\x63he_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04mime\x18\x06 \x01(\t\"\x9a\x02\n\x04\x46ile\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12)\n\x0flarge_thumbnail\x18\x04 \x01(\x0b\x32\x10.proto.Thumbnail\x12)\n\x0fsmall_thumbnail\x18\x05 \x01(\x0b\x32\x10.proto.Thumbnail\x12,\n\x12waveform_thumbnail\x18\x06 \x01(\x0b\x32\x10.proto.Thumbnail\x12\r\n\x05width\x18\x07 \x01(\x05\x12\x0e\n\x06height\x18\x08 \x01(\x05\x12\x10\n\x08\x64uration\x18\t \x01(\x01\x12\x10\n\x08\x63\x61\x63he_id\x18\n \x01(\t\x12\x0c\n\x04mime\x18\x0b \x01(\t\x12\x12\n\npublic_url\x18\x0c \x01(\t\"u\n\x11PostMessageRights\x12\x11\n\tsend_text\x18\x01 \x01(\x08\x12\x12\n\nsend_media\x18\x03 \x01(\x08\x12\x10\n\x08send_gif\x18\x04 \x01(\x08\x12\x14\n\x0csend_sticker\x18\x05 \x01(\x08\x12\x11\n\tsend_link\x18\x06 \x01(\x08\"\xe3\x01\n\nRoomAccess\x12\x13\n\x0bmodify_room\x18\x01 \x01(\x08\x12.\n\x0cpost_message\x18\x02 \x01(\x0b\x32\x18.proto.PostMessageRights\x12\x14\n\x0c\x65\x64it_message\x18\x03 \x01(\x08\x12\x16\n\x0e\x64\x65lete_message\x18\x04 \x01(\x08\x12\x13\n\x0bpin_message\x18\x05 \x01(\x08\x12\x12\n\nadd_member\x18\x06 \x01(\x08\x12\x12\n\nban_member\x18\x07 \x01(\x08\x12\x12\n\nget_member\x18\x08 \x01(\x08\x12\x11\n\tadd_admin\x18\t \x01(\x08\"5\n\tWallpaper\x12\x19\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x0b.proto.File\x12\r\n\x05\x63olor\x18\x02 \x01(\t\"+\n\nPagination\x12\x0e\n\x06offset\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\r\"Z\n\x08\x46\x61vorite\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttextcolor\x18\x02 \x01(\t\x12\x0f\n\x07\x62gcolor\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12\r\n\x05image\x18\x05 \x01(\t\"\xe5\x07\n\x0e\x44iscoveryField\x12\x10\n\x08imageurl\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12:\n\nactiontype\x18\x03 \x01(\x0e\x32&.proto.DiscoveryField.ButtonActionType\x12\x0f\n\x07orderid\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x01(\r\x12\r\n\x05param\x18\x06 \x01(\t\x12\x11\n\tagreement\x18\x07 \x01(\x08\x12\x0f\n\x07refresh\x18\x08 \x01(\x08\x12\x15\n\ragreementSlug\x18\t \x01(\t\"\x8e\x06\n\x10\x42uttonActionType\x12\x08\n\x04NONE\x10\x00\x12\r\n\tJOIN_LINK\x10\x01\x12\x0e\n\nBOT_ACTION\x10\x02\x12\x11\n\rUSERNAME_LINK\x10\x03\x12\x0c\n\x08WEB_LINK\x10\x04\x12\x11\n\rWEB_VIEW_LINK\x10\x05\x12\x0f\n\x0bSTREAM_PLAY\x10\x06\x12\x11\n\rPAY_BY_WALLET\x10\x07\x12\x0e\n\nPAY_DIRECT\x10\x08\x12\x11\n\rREQUEST_PHONE\x10\t\x12\x14\n\x10REQUEST_LOCATION\x10\n\x12\x0e\n\nSHOW_ALERT\x10\x0b\x12\x08\n\x04PAGE\x10\x0c\x12\x12\n\x0e\x46INANCIAL_MENU\x10\r\x12\r\n\tBILL_MENU\x10\x0e\x12\x15\n\x11TRAFFIC_BILL_MENU\x10\x0f\x12\x14\n\x10MOBILE_BILL_MENU\x10\x10\x12\x13\n\x0fPHONE_BILL_MENU\x10\x11\x12\x0e\n\nTOPUP_MENU\x10\x12\x12\x0f\n\x0bWALLET_MENU\x10\x13\x12\x0f\n\x0bNEARBY_MENU\x10\x14\x12\x08\n\x04\x43\x41LL\x10\x15\x12\x10\n\x0cSTICKER_SHOP\x10\x16\x12\t\n\x05IVAND\x10\x17\x12\x0b\n\x07IVANDQR\x10\x18\x12\r\n\tIVANDLIST\x10\x19\x12\x0e\n\nIVANDSCORE\x10\x1a\x12\x10\n\x0c\x43\x41RD_TO_CARD\x10\x1b\x12\x14\n\x10\x46\x41VORITE_CHANNEL\x10\x1c\x12\t\n\x05MUSIC\x10\x1d\x12\x0b\n\x07\x43HARITY\x10\x1e\x12\x0f\n\x0b\x46UN_SERVICE\x10\x1f\x12\x11\n\rVIRTUAL_MONEY\x10 \x12\x10\n\x0c\x43ITY_SERVICE\x10!\x12\x08\n\x04POLL\x10\"\x12\x19\n\x15INTERNET_PACKAGE_MENU\x10#\x12\x15\n\x11\x46INANCIAL_HISTORY\x10$\x12\x11\n\rINVITE_FRIEND\x10%\x12\x08\n\x04NEWS\x10&\x12\x16\n\x12\x45LECTRIC_BILL_MENU\x10\'\x12\x0e\n\nBLOCKCHAIN\x10(\x12\x0c\n\x08PARSLAND\x10)\x12\x0f\n\x0bPOLL_RESULT\x10*\x12\x15\n\x11VIRTUAL_GIFT_CARD\x10+\x12\x0f\n\x0bNEWS_DETAIL\x10,\"\x93\x02\n\tDiscovery\x12.\n\x05model\x18\x01 \x01(\x0e\x32\x1f.proto.Discovery.DiscoveryModel\x12\r\n\x05scale\x18\x02 \x01(\t\x12.\n\x0f\x64iscoveryfields\x18\x03 \x03(\x0b\x32\x15.proto.DiscoveryField\"\x96\x01\n\x0e\x44iscoveryModel\x12\n\n\x06MODEL1\x10\x00\x12\n\n\x06MODEL2\x10\x01\x12\n\n\x06MODEL3\x10\x02\x12\n\n\x06MODEL4\x10\x03\x12\n\n\x06MODEL5\x10\x04\x12\n\n\x06MODEL6\x10\x05\x12\n\n\x06MODEL7\x10\x06\x12\n\n\x06MODEL8\x10\x07\x12\n\n\x06MODEL9\x10\x08\x12\x0b\n\x07MODEL10\x10\t\x12\x0b\n\x07MODEL11\x10\n\"z\n\tPollField\x12\x10\n\x08imageurl\x18\x01 \x01(\t\x12\x0f\n\x07orderid\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\r\x12\x0f\n\x07\x63licked\x18\x04 \x01(\x08\x12\x0b\n\x03sum\x18\x05 \x01(\x04\x12\x11\n\tclickable\x18\x06 \x01(\x08\x12\r\n\x05label\x18\x07 \x01(\t\"x\n\x04Poll\x12.\n\x05model\x18\x01 \x01(\x0e\x32\x1f.proto.Discovery.DiscoveryModel\x12\r\n\x05scale\x18\x02 \x01(\t\x12\x0b\n\x03max\x18\x03 \x01(\r\x12$\n\npollfields\x18\x04 \x03(\x0b\x32\x10.proto.PollField\";\n\rIVandActivity\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x05\x12\x0c\n\x04time\x18\x03 \x01(\r\"\x92\x02\n\x07MplSale\x12\x16\n\x0einvoice_number\x18\x01 \x01(\x04\x12\x14\n\x0c\x66rom_user_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\x12\x14\n\x0ctrace_number\x18\x04 \x01(\x03\x12\x10\n\x08pay_time\x18\x05 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x13\n\x0b\x63\x61rd_number\x18\x07 \x01(\t\x12\x0b\n\x03rrn\x18\x08 \x01(\x03\x12%\n\x06status\x18\t \x01(\x0e\x32\x15.proto.MplSale.Status\"C\n\x06Status\x12\x12\n\x0ePENDING_VERIFY\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0c\n\x08REVERSED\x10\x03\"\xcb\n\n\x0eMplTransaction\x12\x10\n\x08order_id\x18\x01 \x01(\x04\x12\r\n\x05token\x18\x02 \x01(\t\x12\x10\n\x08pay_time\x18\x03 \x01(\r\x12(\n\x04type\x18\x04 \x01(\x0e\x32\x1a.proto.MplTransaction.Type\x12(\n\x04\x62ill\x18\x05 \x01(\x0b\x32\x1a.proto.MplTransaction.Bill\x12*\n\x05topup\x18\x06 \x01(\x0b\x32\x1b.proto.MplTransaction.Topup\x12*\n\x05sales\x18\x07 \x01(\x0b\x32\x1b.proto.MplTransaction.Sales\x12\x34\n\ncardtocard\x18\x08 \x01(\x0b\x32 .proto.MplTransaction.CardToCard\x1a\xf8\x01\n\x04\x42ill\x12\x0e\n\x06\x42illId\x18\x01 \x01(\t\x12\r\n\x05PayId\x18\x02 \x01(\t\x12\x10\n\x08\x42illType\x18\x03 \x01(\t\x12\x0e\n\x06Status\x18\x04 \x01(\r\x12\x0e\n\x06\x41mount\x18\x05 \x01(\x04\x12\x12\n\nCardNumber\x18\x06 \x01(\t\x12\x14\n\x0cMerchantName\x18\x07 \x01(\t\x12\x0f\n\x07OrderId\x18\x08 \x01(\x04\x12\x17\n\x0fRequestDateTime\x18\t \x01(\x04\x12\x0b\n\x03RRN\x18\n \x01(\x04\x12\x19\n\x11StatusDescription\x18\x0b \x01(\t\x12\x12\n\nTerminalNo\x18\x0c \x01(\r\x12\x0f\n\x07TraceNo\x18\r \x01(\r\x1a\x96\x02\n\x05Topup\x12\x1d\n\x15RequesterMobileNumber\x18\x01 \x01(\x04\x12\x1a\n\x12\x43hargeMobileNumber\x18\x02 \x01(\x04\x12\x11\n\tTopupType\x18\x03 \x01(\r\x12\x0e\n\x06Status\x18\x04 \x01(\r\x12\x0e\n\x06\x41mount\x18\x05 \x01(\x04\x12\x12\n\nCardNumber\x18\x06 \x01(\t\x12\x14\n\x0cMerchantName\x18\x07 \x01(\t\x12\x0f\n\x07OrderId\x18\x08 \x01(\x04\x12\x17\n\x0fRequestDateTime\x18\t \x01(\x04\x12\x0b\n\x03RRN\x18\n \x01(\x04\x12\x19\n\x11StatusDescription\x18\x0b \x01(\t\x12\x12\n\nTerminalNo\x18\x0c \x01(\r\x12\x0f\n\x07TraceNo\x18\r \x01(\r\x1a\xc8\x01\n\x05Sales\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x04\x12\x12\n\nCardNumber\x18\x03 \x01(\t\x12\x14\n\x0cMerchantName\x18\x04 \x01(\t\x12\x0f\n\x07OrderId\x18\x05 \x01(\x04\x12\x17\n\x0fRequestDateTime\x18\x06 \x01(\x04\x12\x0b\n\x03RRN\x18\x07 \x01(\x04\x12\x19\n\x11StatusDescription\x18\x08 \x01(\t\x12\x12\n\nTerminalNo\x18\t \x01(\r\x12\x0f\n\x07TraceNo\x18\n \x01(\r\x1a\x80\x02\n\nCardToCard\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x04\x12\x18\n\x10SourceCardNumber\x18\x03 \x01(\t\x12\x16\n\x0e\x44\x65stCardNumber\x18\x04 \x01(\t\x12\x10\n\x08\x42\x61nkName\x18\x05 \x01(\t\x12\x14\n\x0c\x44\x65stBankName\x18\x06 \x01(\t\x12\x15\n\rCardOwnerName\x18\x07 \x01(\t\x12\x0f\n\x07OrderId\x18\x08 \x01(\x04\x12\x17\n\x0fRequestDateTime\x18\t \x01(\x04\x12\x0b\n\x03RRN\x18\n \x01(\x04\x12\x19\n\x11StatusDescription\x18\x0b \x01(\t\x12\x0f\n\x07TraceNo\x18\r \x01(\r\"B\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x42ILL\x10\x01\x12\t\n\x05TOPUP\x10\x02\x12\t\n\x05SALES\x10\x03\x12\x10\n\x0c\x43\x41RD_TO_CARD\x10\x04*+\n\x06Gender\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02*<\n\x06\x44\x65vice\x12\x12\n\x0eUNKNOWN_DEVICE\x10\x00\x12\x06\n\x02PC\x10\x01\x12\n\n\x06TABLET\x10\x02\x12\n\n\x06MOBILE\x10\x03*k\n\x08Platform\x12\x14\n\x10UNKNOWN_PLATFORM\x10\x00\x12\x0b\n\x07\x41NDROID\x10\x01\x12\x07\n\x03IOS\x10\x02\x12\n\n\x06MAC_OS\x10\x03\x12\x0b\n\x07WINDOWS\x10\x04\x12\t\n\x05LINUX\x10\x05\x12\x0f\n\x0b\x42LACK_BERRY\x10\x06* \n\x08Language\x12\t\n\x05\x45N_US\x10\x00\x12\t\n\x05\x46\x41_IR\x10\x01*\xe4\x01\n\x0fRoomMessageType\x12\x08\n\x04TEXT\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\x0e\n\nIMAGE_TEXT\x10\x02\x12\t\n\x05VIDEO\x10\x03\x12\x0e\n\nVIDEO_TEXT\x10\x04\x12\t\n\x05\x41UDIO\x10\x05\x12\x0e\n\nAUDIO_TEXT\x10\x06\x12\t\n\x05VOICE\x10\x07\x12\x07\n\x03GIF\x10\x08\x12\x0c\n\x08GIF_TEXT\x10\x0e\x12\x08\n\x04\x46ILE\x10\t\x12\r\n\tFILE_TEXT\x10\n\x12\x0c\n\x08LOCATION\x10\x0b\x12\x07\n\x03LOG\x10\x0c\x12\x0b\n\x07\x43ONTACT\x10\r\x12\n\n\x06WALLET\x10\x0f\x12\x0b\n\x07STICKER\x10\x10*]\n\x11RoomMessageStatus\x12\n\n\x06\x46\x41ILED\x10\x00\x12\x0b\n\x07SENDING\x10\x01\x12\x08\n\x04SENT\x10\x02\x12\r\n\tDELIVERED\x10\x03\x12\x08\n\x04SEEN\x10\x04\x12\x0c\n\x08LISTENED\x10\x05*5\n\x13RoomMessageReaction\x12\r\n\tTHUMBS_UP\x10\x00\x12\x0f\n\x0bTHUMBS_DOWN\x10\x01*\xa4\x02\n\x0c\x43lientAction\x12\n\n\x06\x43\x41NCEL\x10\x00\x12\n\n\x06TYPING\x10\x01\x12\x11\n\rSENDING_IMAGE\x10\x02\x12\x13\n\x0f\x43\x41PTURING_IMAGE\x10\x03\x12\x11\n\rSENDING_VIDEO\x10\x04\x12\x13\n\x0f\x43\x41PTURING_VIDEO\x10\x05\x12\x11\n\rSENDING_AUDIO\x10\x06\x12\x13\n\x0fRECORDING_VOICE\x10\x07\x12\x11\n\rSENDING_VOICE\x10\x08\x12\x14\n\x10SENDING_DOCUMENT\x10\t\x12\x0f\n\x0bSENDING_GIF\x10\n\x12\x10\n\x0cSENDING_FILE\x10\x0b\x12\x14\n\x10SENDING_LOCATION\x10\x0c\x12\x14\n\x10\x43HOOSING_CONTACT\x10\r\x12\x0c\n\x08PAINTING\x10\x0e* \n\x08RoomMute\x12\n\n\x06UNMUTE\x10\x00\x12\x08\n\x04MUTE\x10\x01*\x9b\x01\n\x0bPrivacyType\x12\x0f\n\x0bUSER_STATUS\x10\x00\x12\n\n\x06\x41VATAR\x10\x01\x12\x10\n\x0cGROUP_INVITE\x10\x02\x12\x12\n\x0e\x43HANNEL_INVITE\x10\x03\x12\x11\n\rVOICE_CALLING\x10\x04\x12\x11\n\rVIDEO_CALLING\x10\x05\x12\x12\n\x0eSCREEN_SHARING\x10\x06\x12\x0f\n\x0bSECRET_CHAT\x10\x07*?\n\x0cPrivacyLevel\x12\r\n\tALLOW_ALL\x10\x00\x12\x0c\n\x08\x44\x45NY_ALL\x10\x01\x12\x12\n\x0e\x41LLOW_CONTACTS\x10\x02\x42\x1d\n\x0enet.iGap.protoB\x0bProtoGlobalb\x06proto3')
  ,
  dependencies=[GroupChangeMemberRights__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_GENDER = _descriptor.EnumDescriptor(
  name='Gender',
  full_name='proto.Gender',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEMALE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10393,
  serialized_end=10436,
)
_sym_db.RegisterEnumDescriptor(_GENDER)

Gender = enum_type_wrapper.EnumTypeWrapper(_GENDER)
_DEVICE = _descriptor.EnumDescriptor(
  name='Device',
  full_name='proto.Device',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_DEVICE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PC', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TABLET', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOBILE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10438,
  serialized_end=10498,
)
_sym_db.RegisterEnumDescriptor(_DEVICE)

Device = enum_type_wrapper.EnumTypeWrapper(_DEVICE)
_PLATFORM = _descriptor.EnumDescriptor(
  name='Platform',
  full_name='proto.Platform',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_PLATFORM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAC_OS', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WINDOWS', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINUX', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLACK_BERRY', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10500,
  serialized_end=10607,
)
_sym_db.RegisterEnumDescriptor(_PLATFORM)

Platform = enum_type_wrapper.EnumTypeWrapper(_PLATFORM)
_LANGUAGE = _descriptor.EnumDescriptor(
  name='Language',
  full_name='proto.Language',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EN_US', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FA_IR', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10609,
  serialized_end=10641,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGE)

Language = enum_type_wrapper.EnumTypeWrapper(_LANGUAGE)
_ROOMMESSAGETYPE = _descriptor.EnumDescriptor(
  name='RoomMessageType',
  full_name='proto.RoomMessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_TEXT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_TEXT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDIO', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDIO_TEXT', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VOICE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GIF', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GIF_TEXT', index=9, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=10, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE_TEXT', index=11, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION', index=12, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOG', index=13, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTACT', index=14, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WALLET', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STICKER', index=16, number=16,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10644,
  serialized_end=10872,
)
_sym_db.RegisterEnumDescriptor(_ROOMMESSAGETYPE)

RoomMessageType = enum_type_wrapper.EnumTypeWrapper(_ROOMMESSAGETYPE)
_ROOMMESSAGESTATUS = _descriptor.EnumDescriptor(
  name='RoomMessageStatus',
  full_name='proto.RoomMessageStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELIVERED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEEN', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTENED', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10874,
  serialized_end=10967,
)
_sym_db.RegisterEnumDescriptor(_ROOMMESSAGESTATUS)

RoomMessageStatus = enum_type_wrapper.EnumTypeWrapper(_ROOMMESSAGESTATUS)
_ROOMMESSAGEREACTION = _descriptor.EnumDescriptor(
  name='RoomMessageReaction',
  full_name='proto.RoomMessageReaction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THUMBS_UP', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THUMBS_DOWN', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10969,
  serialized_end=11022,
)
_sym_db.RegisterEnumDescriptor(_ROOMMESSAGEREACTION)

RoomMessageReaction = enum_type_wrapper.EnumTypeWrapper(_ROOMMESSAGEREACTION)
_CLIENTACTION = _descriptor.EnumDescriptor(
  name='ClientAction',
  full_name='proto.ClientAction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CANCEL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TYPING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING_IMAGE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAPTURING_IMAGE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING_VIDEO', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAPTURING_VIDEO', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING_AUDIO', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORDING_VOICE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING_VOICE', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING_DOCUMENT', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING_GIF', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING_FILE', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENDING_LOCATION', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHOOSING_CONTACT', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAINTING', index=14, number=14,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11025,
  serialized_end=11317,
)
_sym_db.RegisterEnumDescriptor(_CLIENTACTION)

ClientAction = enum_type_wrapper.EnumTypeWrapper(_CLIENTACTION)
_ROOMMUTE = _descriptor.EnumDescriptor(
  name='RoomMute',
  full_name='proto.RoomMute',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNMUTE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUTE', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11319,
  serialized_end=11351,
)
_sym_db.RegisterEnumDescriptor(_ROOMMUTE)

RoomMute = enum_type_wrapper.EnumTypeWrapper(_ROOMMUTE)
_PRIVACYTYPE = _descriptor.EnumDescriptor(
  name='PrivacyType',
  full_name='proto.PrivacyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER_STATUS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVATAR', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP_INVITE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_INVITE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VOICE_CALLING', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_CALLING', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCREEN_SHARING', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECRET_CHAT', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11354,
  serialized_end=11509,
)
_sym_db.RegisterEnumDescriptor(_PRIVACYTYPE)

PrivacyType = enum_type_wrapper.EnumTypeWrapper(_PRIVACYTYPE)
_PRIVACYLEVEL = _descriptor.EnumDescriptor(
  name='PrivacyLevel',
  full_name='proto.PrivacyLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALLOW_ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DENY_ALL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALLOW_CONTACTS', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11511,
  serialized_end=11574,
)
_sym_db.RegisterEnumDescriptor(_PRIVACYLEVEL)

PrivacyLevel = enum_type_wrapper.EnumTypeWrapper(_PRIVACYLEVEL)
UNKNOWN = 0
MALE = 1
FEMALE = 2
UNKNOWN_DEVICE = 0
PC = 1
TABLET = 2
MOBILE = 3
UNKNOWN_PLATFORM = 0
ANDROID = 1
IOS = 2
MAC_OS = 3
WINDOWS = 4
LINUX = 5
BLACK_BERRY = 6
EN_US = 0
FA_IR = 1
TEXT = 0
IMAGE = 1
IMAGE_TEXT = 2
VIDEO = 3
VIDEO_TEXT = 4
AUDIO = 5
AUDIO_TEXT = 6
VOICE = 7
GIF = 8
GIF_TEXT = 14
FILE = 9
FILE_TEXT = 10
LOCATION = 11
LOG = 12
CONTACT = 13
WALLET = 15
STICKER = 16
FAILED = 0
SENDING = 1
SENT = 2
DELIVERED = 3
SEEN = 4
LISTENED = 5
THUMBS_UP = 0
THUMBS_DOWN = 1
CANCEL = 0
TYPING = 1
SENDING_IMAGE = 2
CAPTURING_IMAGE = 3
SENDING_VIDEO = 4
CAPTURING_VIDEO = 5
SENDING_AUDIO = 6
RECORDING_VOICE = 7
SENDING_VOICE = 8
SENDING_DOCUMENT = 9
SENDING_GIF = 10
SENDING_FILE = 11
SENDING_LOCATION = 12
CHOOSING_CONTACT = 13
PAINTING = 14
UNMUTE = 0
MUTE = 1
USER_STATUS = 0
AVATAR = 1
GROUP_INVITE = 2
CHANNEL_INVITE = 3
VOICE_CALLING = 4
VIDEO_CALLING = 5
SCREEN_SHARING = 6
SECRET_CHAT = 7
ALLOW_ALL = 0
DENY_ALL = 1
ALLOW_CONTACTS = 2


_ROOMMESSAGELOG_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.RoomMessageLog.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER_JOINED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_DELETED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROOM_CREATED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEMBER_ADDED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEMBER_KICKED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEMBER_LEFT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROOM_CONVERTED_TO_PUBLIC', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROOM_CONVERTED_TO_PRIVATE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEMBER_JOINED_BY_INVITE_LINK', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROOM_DELETED', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSED_VOICE_CALL', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSED_VIDEO_CALL', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSED_SCREEN_SHARE', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSED_SECRET_CHAT', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PINNED_MESSAGE', index=14, number=14,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=299,
  serialized_end=640,
)
_sym_db.RegisterEnumDescriptor(_ROOMMESSAGELOG_TYPE)

_ROOMMESSAGELOG_EXTRATYPE = _descriptor.EnumDescriptor(
  name='ExtraType',
  full_name='proto.RoomMessageLog.ExtraType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_EXTRA', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_USER', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=642,
  serialized_end=684,
)
_sym_db.RegisterEnumDescriptor(_ROOMMESSAGELOG_EXTRATYPE)

_ROOMMESSAGEWALLET_TOPUP_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.RoomMessageWallet.Topup.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_PREPAID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_WOW', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_WIMAX', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_POSTPAID', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MCI', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RIGHTEL', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1953,
  serialized_end=2064,
)
_sym_db.RegisterEnumDescriptor(_ROOMMESSAGEWALLET_TOPUP_TYPE)

_ROOMMESSAGEWALLET_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.RoomMessageWallet.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MONEY_TRANSFER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TO_CARD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOPUP', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BILL', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2382,
  serialized_end=2460,
)
_sym_db.RegisterEnumDescriptor(_ROOMMESSAGEWALLET_TYPE)

_REGISTEREDUSER_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.RegisteredUser.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LONG_TIME_AGO', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAST_MONTH', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAST_WEEK', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLINE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXACTLY', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECENTLY', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPPORT', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_NOTIFICATIONS', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2897,
  serialized_end=3034,
)
_sym_db.RegisterEnumDescriptor(_REGISTEREDUSER_STATUS)

_ROOMMESSAGE_EXTRATYPE = _descriptor.EnumDescriptor(
  name='ExtraType',
  full_name='proto.RoomMessage.ExtraType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_EXTRA', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_EXTRA', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4171,
  serialized_end=4215,
)
_sym_db.RegisterEnumDescriptor(_ROOMMESSAGE_EXTRATYPE)

_ROOM_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.Room.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHAT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4879,
  serialized_end=4919,
)
_sym_db.RegisterEnumDescriptor(_ROOM_TYPE)

_GROUPROOM_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.GroupRoom.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRIVATE_ROOM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC_ROOM', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5532,
  serialized_end=5573,
)
_sym_db.RegisterEnumDescriptor(_GROUPROOM_TYPE)

_GROUPROOM_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='proto.GroupRoom.Role',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MEMBER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODERATOR', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADMIN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OWNER', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5575,
  serialized_end=5630,
)
_sym_db.RegisterEnumDescriptor(_GROUPROOM_ROLE)

_CHANNELROOM_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.ChannelRoom.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRIVATE_ROOM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC_ROOM', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5532,
  serialized_end=5573,
)
_sym_db.RegisterEnumDescriptor(_CHANNELROOM_TYPE)

_CHANNELROOM_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='proto.ChannelRoom.Role',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MEMBER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODERATOR', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADMIN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OWNER', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5575,
  serialized_end=5630,
)
_sym_db.RegisterEnumDescriptor(_CHANNELROOM_ROLE)

_DISCOVERYFIELD_BUTTONACTIONTYPE = _descriptor.EnumDescriptor(
  name='ButtonActionType',
  full_name='proto.DiscoveryField.ButtonActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOIN_LINK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_ACTION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USERNAME_LINK', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEB_LINK', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEB_VIEW_LINK', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STREAM_PLAY', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAY_BY_WALLET', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAY_DIRECT', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUEST_PHONE', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUEST_LOCATION', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOW_ALERT', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAGE', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINANCIAL_MENU', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BILL_MENU', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_BILL_MENU', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOBILE_BILL_MENU', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PHONE_BILL_MENU', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOPUP_MENU', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WALLET_MENU', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEARBY_MENU', index=20, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALL', index=21, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STICKER_SHOP', index=22, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IVAND', index=23, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IVANDQR', index=24, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IVANDLIST', index=25, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IVANDSCORE', index=26, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TO_CARD', index=27, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAVORITE_CHANNEL', index=28, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUSIC', index=29, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHARITY', index=30, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FUN_SERVICE', index=31, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL_MONEY', index=32, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CITY_SERVICE', index=33, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLL', index=34, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNET_PACKAGE_MENU', index=35, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINANCIAL_HISTORY', index=36, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVITE_FRIEND', index=37, number=37,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEWS', index=38, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ELECTRIC_BILL_MENU', index=39, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCKCHAIN', index=40, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARSLAND', index=41, number=41,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLL_RESULT', index=42, number=42,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL_GIFT_CARD', index=43, number=43,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEWS_DETAIL', index=44, number=44,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7389,
  serialized_end=8171,
)
_sym_db.RegisterEnumDescriptor(_DISCOVERYFIELD_BUTTONACTIONTYPE)

_DISCOVERY_DISCOVERYMODEL = _descriptor.EnumDescriptor(
  name='DiscoveryModel',
  full_name='proto.Discovery.DiscoveryModel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODEL1', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL2', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL3', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL4', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL5', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL6', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL7', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL8', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL9', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL10', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL11', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8299,
  serialized_end=8449,
)
_sym_db.RegisterEnumDescriptor(_DISCOVERY_DISCOVERYMODEL)

_MPLSALE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='proto.MplSale.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING_VERIFY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REVERSED', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8966,
  serialized_end=9033,
)
_sym_db.RegisterEnumDescriptor(_MPLSALE_STATUS)

_MPLTRANSACTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.MplTransaction.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BILL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOPUP', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SALES', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARD_TO_CARD', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10325,
  serialized_end=10391,
)
_sym_db.RegisterEnumDescriptor(_MPLTRANSACTION_TYPE)


_ROOMMESSAGELOCATION = _descriptor.Descriptor(
  name='RoomMessageLocation',
  full_name='proto.RoomMessageLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat', full_name='proto.RoomMessageLocation.lat', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lon', full_name='proto.RoomMessageLocation.lon', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=101,
)


_ROOMMESSAGELOG_TARGETUSER = _descriptor.Descriptor(
  name='TargetUser',
  full_name='proto.RoomMessageLog.TargetUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.RoomMessageLog.TargetUser.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=296,
)

_ROOMMESSAGELOG = _descriptor.Descriptor(
  name='RoomMessageLog',
  full_name='proto.RoomMessageLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.RoomMessageLog.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extra_type', full_name='proto.RoomMessageLog.extra_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_user', full_name='proto.RoomMessageLog.target_user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ROOMMESSAGELOG_TARGETUSER, ],
  enum_types=[
    _ROOMMESSAGELOG_TYPE,
    _ROOMMESSAGELOG_EXTRATYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=684,
)


_ROOMMESSAGECONTACT = _descriptor.Descriptor(
  name='RoomMessageContact',
  full_name='proto.RoomMessageContact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.RoomMessageContact.first_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.RoomMessageContact.last_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nickname', full_name='proto.RoomMessageContact.nickname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.RoomMessageContact.phone', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='email', full_name='proto.RoomMessageContact.email', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=793,
)


_ROOMMESSAGEWALLET_MONEYTRANSFER = _descriptor.Descriptor(
  name='MoneyTransfer',
  full_name='proto.RoomMessageWallet.MoneyTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_user_id', full_name='proto.RoomMessageWallet.MoneyTransfer.from_user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='proto.RoomMessageWallet.MoneyTransfer.to_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.RoomMessageWallet.MoneyTransfer.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trace_number', full_name='proto.RoomMessageWallet.MoneyTransfer.trace_number', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invoice_number', full_name='proto.RoomMessageWallet.MoneyTransfer.invoice_number', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pay_time', full_name='proto.RoomMessageWallet.MoneyTransfer.pay_time', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.RoomMessageWallet.MoneyTransfer.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='card_number', full_name='proto.RoomMessageWallet.MoneyTransfer.card_number', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rrn', full_name='proto.RoomMessageWallet.MoneyTransfer.rrn', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=1270,
)

_ROOMMESSAGEWALLET_CARDTOCARD = _descriptor.Descriptor(
  name='CardToCard',
  full_name='proto.RoomMessageWallet.CardToCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_user_id', full_name='proto.RoomMessageWallet.CardToCard.from_user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='proto.RoomMessageWallet.CardToCard.to_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='proto.RoomMessageWallet.CardToCard.order_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.RoomMessageWallet.CardToCard.token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.RoomMessageWallet.CardToCard.amount', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source_card_number', full_name='proto.RoomMessageWallet.CardToCard.source_card_number', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dest_card_number', full_name='proto.RoomMessageWallet.CardToCard.dest_card_number', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='proto.RoomMessageWallet.CardToCard.request_time', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rrn', full_name='proto.RoomMessageWallet.CardToCard.rrn', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trace_number', full_name='proto.RoomMessageWallet.CardToCard.trace_number', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bankName', full_name='proto.RoomMessageWallet.CardToCard.bankName', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='destBankName', full_name='proto.RoomMessageWallet.CardToCard.destBankName', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cardOwnerName', full_name='proto.RoomMessageWallet.CardToCard.cardOwnerName', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.RoomMessageWallet.CardToCard.status', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1273,
  serialized_end=1566,
)

_ROOMMESSAGEWALLET_TOPUP = _descriptor.Descriptor(
  name='Topup',
  full_name='proto.RoomMessageWallet.Topup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_user_id', full_name='proto.RoomMessageWallet.Topup.from_user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='proto.RoomMessageWallet.Topup.order_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='my_token', full_name='proto.RoomMessageWallet.Topup.my_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.RoomMessageWallet.Topup.token', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.RoomMessageWallet.Topup.amount', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requester_mobile_number', full_name='proto.RoomMessageWallet.Topup.requester_mobile_number', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='charge_mobile_number', full_name='proto.RoomMessageWallet.Topup.charge_mobile_number', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topup_type', full_name='proto.RoomMessageWallet.Topup.topup_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='card_number', full_name='proto.RoomMessageWallet.Topup.card_number', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='merchant_name', full_name='proto.RoomMessageWallet.Topup.merchant_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminal_no', full_name='proto.RoomMessageWallet.Topup.terminal_no', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rrn', full_name='proto.RoomMessageWallet.Topup.rrn', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trace_number', full_name='proto.RoomMessageWallet.Topup.trace_number', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='proto.RoomMessageWallet.Topup.request_time', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.RoomMessageWallet.Topup.status', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_description', full_name='proto.RoomMessageWallet.Topup.status_description', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROOMMESSAGEWALLET_TOPUP_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1569,
  serialized_end=2064,
)

_ROOMMESSAGEWALLET_BILL = _descriptor.Descriptor(
  name='Bill',
  full_name='proto.RoomMessageWallet.Bill',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_user_id', full_name='proto.RoomMessageWallet.Bill.from_user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='proto.RoomMessageWallet.Bill.order_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='my_token', full_name='proto.RoomMessageWallet.Bill.my_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.RoomMessageWallet.Bill.token', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.RoomMessageWallet.Bill.amount', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pay_id', full_name='proto.RoomMessageWallet.Bill.pay_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bill_id', full_name='proto.RoomMessageWallet.Bill.bill_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bill_type', full_name='proto.RoomMessageWallet.Bill.bill_type', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='card_number', full_name='proto.RoomMessageWallet.Bill.card_number', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='merchant_name', full_name='proto.RoomMessageWallet.Bill.merchant_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminal_no', full_name='proto.RoomMessageWallet.Bill.terminal_no', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rrn', full_name='proto.RoomMessageWallet.Bill.rrn', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trace_number', full_name='proto.RoomMessageWallet.Bill.trace_number', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='proto.RoomMessageWallet.Bill.request_time', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.RoomMessageWallet.Bill.status', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_description', full_name='proto.RoomMessageWallet.Bill.status_description', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2067,
  serialized_end=2380,
)

_ROOMMESSAGEWALLET = _descriptor.Descriptor(
  name='RoomMessageWallet',
  full_name='proto.RoomMessageWallet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.RoomMessageWallet.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='money_transfer', full_name='proto.RoomMessageWallet.money_transfer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='card_to_card', full_name='proto.RoomMessageWallet.card_to_card', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topup', full_name='proto.RoomMessageWallet.topup', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bill', full_name='proto.RoomMessageWallet.bill', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ROOMMESSAGEWALLET_MONEYTRANSFER, _ROOMMESSAGEWALLET_CARDTOCARD, _ROOMMESSAGEWALLET_TOPUP, _ROOMMESSAGEWALLET_BILL, ],
  enum_types=[
    _ROOMMESSAGEWALLET_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=2460,
)


_ROOMMESSAGEFORWARDFROM = _descriptor.Descriptor(
  name='RoomMessageForwardFrom',
  full_name='proto.RoomMessageForwardFrom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.RoomMessageForwardFrom.room_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.RoomMessageForwardFrom.message_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2462,
  serialized_end=2523,
)


_REGISTEREDUSER = _descriptor.Descriptor(
  name='RegisteredUser',
  full_name='proto.RegisteredUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.RegisteredUser.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.RegisteredUser.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone', full_name='proto.RegisteredUser.phone', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='proto.RegisteredUser.first_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='proto.RegisteredUser.last_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='proto.RegisteredUser.display_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initials', full_name='proto.RegisteredUser.initials', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='proto.RegisteredUser.color', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.RegisteredUser.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen', full_name='proto.RegisteredUser.last_seen', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avatar_count', full_name='proto.RegisteredUser.avatar_count', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='proto.RegisteredUser.avatar', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mutual', full_name='proto.RegisteredUser.mutual', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='proto.RegisteredUser.deleted', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_id', full_name='proto.RegisteredUser.cache_id', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bio', full_name='proto.RegisteredUser.bio', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='verified', full_name='proto.RegisteredUser.verified', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bot', full_name='proto.RegisteredUser.bot', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REGISTEREDUSER_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2526,
  serialized_end=3034,
)


_AVATAR = _descriptor.Descriptor(
  name='Avatar',
  full_name='proto.Avatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.Avatar.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file', full_name='proto.Avatar.file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3036,
  serialized_end=3083,
)


_ROOMMESSAGE_AUTHOR_USER = _descriptor.Descriptor(
  name='User',
  full_name='proto.RoomMessage.Author.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.RoomMessage.Author.User.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_id', full_name='proto.RoomMessage.Author.User.cache_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3995,
  serialized_end=4036,
)

_ROOMMESSAGE_AUTHOR_ROOM = _descriptor.Descriptor(
  name='Room',
  full_name='proto.RoomMessage.Author.Room',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.RoomMessage.Author.Room.room_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4038,
  serialized_end=4061,
)

_ROOMMESSAGE_AUTHOR = _descriptor.Descriptor(
  name='Author',
  full_name='proto.RoomMessage.Author',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='proto.RoomMessage.Author.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user', full_name='proto.RoomMessage.Author.user', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room', full_name='proto.RoomMessage.Author.room', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ROOMMESSAGE_AUTHOR_USER, _ROOMMESSAGE_AUTHOR_ROOM, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3879,
  serialized_end=4061,
)

_ROOMMESSAGE_CHANNELEXTRA = _descriptor.Descriptor(
  name='ChannelExtra',
  full_name='proto.RoomMessage.ChannelExtra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='proto.RoomMessage.ChannelExtra.signature', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='views_label', full_name='proto.RoomMessage.ChannelExtra.views_label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='thumbs_up_label', full_name='proto.RoomMessage.ChannelExtra.thumbs_up_label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='thumbs_down_label', full_name='proto.RoomMessage.ChannelExtra.thumbs_down_label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4063,
  serialized_end=4169,
)

_ROOMMESSAGE = _descriptor.Descriptor(
  name='RoomMessage',
  full_name='proto.RoomMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='proto.RoomMessage.message_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_version', full_name='proto.RoomMessage.message_version', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.RoomMessage.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_version', full_name='proto.RoomMessage.status_version', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='proto.RoomMessage.message_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.RoomMessage.message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attachment', full_name='proto.RoomMessage.attachment', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='author', full_name='proto.RoomMessage.author', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='proto.RoomMessage.location', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='log', full_name='proto.RoomMessage.log', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contact', full_name='proto.RoomMessage.contact', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='proto.RoomMessage.wallet', index=11,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edited', full_name='proto.RoomMessage.edited', index=12,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='proto.RoomMessage.create_time', index=13,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='proto.RoomMessage.update_time', index=14,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='proto.RoomMessage.deleted', index=15,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='forward_from', full_name='proto.RoomMessage.forward_from', index=16,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_to', full_name='proto.RoomMessage.reply_to', index=17,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='previous_message_id', full_name='proto.RoomMessage.previous_message_id', index=18,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_id', full_name='proto.RoomMessage.random_id', index=19,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_type', full_name='proto.RoomMessage.additional_type', index=20,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_data', full_name='proto.RoomMessage.additional_data', index=21,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='extra_type', full_name='proto.RoomMessage.extra_type', index=22,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_extra', full_name='proto.RoomMessage.channel_extra', index=23,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ROOMMESSAGE_AUTHOR, _ROOMMESSAGE_CHANNELEXTRA, ],
  enum_types=[
    _ROOMMESSAGE_EXTRATYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3086,
  serialized_end=4215,
)


_ROOMDRAFT = _descriptor.Descriptor(
  name='RoomDraft',
  full_name='proto.RoomDraft',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.RoomDraft.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_to', full_name='proto.RoomDraft.reply_to', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='draft_time', full_name='proto.RoomDraft.draft_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4217,
  serialized_end=4283,
)


_ROOM = _descriptor.Descriptor(
  name='Room',
  full_name='proto.Room',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.Room.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.Room.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='proto.Room.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initials', full_name='proto.Room.initials', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='proto.Room.color', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unread_count', full_name='proto.Room.unread_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_message', full_name='proto.Room.last_message', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_only', full_name='proto.Room.read_only', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_participant', full_name='proto.Room.is_participant', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='draft', full_name='proto.Room.draft', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_unread_message', full_name='proto.Room.first_unread_message', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_mute', full_name='proto.Room.room_mute', index=11,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_id', full_name='proto.Room.pin_id', index=12,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pinned_message', full_name='proto.Room.pinned_message', index=13,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priority', full_name='proto.Room.priority', index=14,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='chat_room_extra', full_name='proto.Room.chat_room_extra', index=15,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_room_extra', full_name='proto.Room.group_room_extra', index=16,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channel_room_extra', full_name='proto.Room.channel_room_extra', index=17,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.Room.app_id', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='proto.Room.permission', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROOM_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4286,
  serialized_end=4919,
)


_CHATROOM = _descriptor.Descriptor(
  name='ChatRoom',
  full_name='proto.ChatRoom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='proto.ChatRoom.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4921,
  serialized_end=4968,
)


_GROUPROOM_PRIVATEEXTRA = _descriptor.Descriptor(
  name='PrivateExtra',
  full_name='proto.GroupRoom.PrivateExtra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_link', full_name='proto.GroupRoom.PrivateExtra.invite_link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invite_token', full_name='proto.GroupRoom.PrivateExtra.invite_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5440,
  serialized_end=5497,
)

_GROUPROOM_PUBLICEXTRA = _descriptor.Descriptor(
  name='PublicExtra',
  full_name='proto.GroupRoom.PublicExtra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.GroupRoom.PublicExtra.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5499,
  serialized_end=5530,
)

_GROUPROOM = _descriptor.Descriptor(
  name='GroupRoom',
  full_name='proto.GroupRoom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.GroupRoom.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.GroupRoom.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participants_count', full_name='proto.GroupRoom.participants_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participants_count_label', full_name='proto.GroupRoom.participants_count_label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participants_count_limit', full_name='proto.GroupRoom.participants_count_limit', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participants_count_limit_label', full_name='proto.GroupRoom.participants_count_limit_label', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.GroupRoom.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avatar_count', full_name='proto.GroupRoom.avatar_count', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='proto.GroupRoom.avatar', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_extra', full_name='proto.GroupRoom.private_extra', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_extra', full_name='proto.GroupRoom.public_extra', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_rights', full_name='proto.GroupRoom.room_rights', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GROUPROOM_PRIVATEEXTRA, _GROUPROOM_PUBLICEXTRA, ],
  enum_types=[
    _GROUPROOM_TYPE,
    _GROUPROOM_ROLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4971,
  serialized_end=5630,
)


_CHANNELROOM_PRIVATEEXTRA = _descriptor.Descriptor(
  name='PrivateExtra',
  full_name='proto.ChannelRoom.PrivateExtra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_link', full_name='proto.ChannelRoom.PrivateExtra.invite_link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invite_token', full_name='proto.ChannelRoom.PrivateExtra.invite_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5440,
  serialized_end=5497,
)

_CHANNELROOM_PUBLICEXTRA = _descriptor.Descriptor(
  name='PublicExtra',
  full_name='proto.ChannelRoom.PublicExtra',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.ChannelRoom.PublicExtra.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5499,
  serialized_end=5530,
)

_CHANNELROOM = _descriptor.Descriptor(
  name='ChannelRoom',
  full_name='proto.ChannelRoom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.ChannelRoom.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.ChannelRoom.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participants_count', full_name='proto.ChannelRoom.participants_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='participants_count_label', full_name='proto.ChannelRoom.participants_count_label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.ChannelRoom.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avatar_count', full_name='proto.ChannelRoom.avatar_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='proto.ChannelRoom.avatar', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='private_extra', full_name='proto.ChannelRoom.private_extra', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_extra', full_name='proto.ChannelRoom.public_extra', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signature', full_name='proto.ChannelRoom.signature', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seen_id', full_name='proto.ChannelRoom.seen_id', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='verified', full_name='proto.ChannelRoom.verified', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reaction_status', full_name='proto.ChannelRoom.reaction_status', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CHANNELROOM_PRIVATEEXTRA, _CHANNELROOM_PUBLICEXTRA, ],
  enum_types=[
    _CHANNELROOM_TYPE,
    _CHANNELROOM_ROLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5633,
  serialized_end=6241,
)


_THUMBNAIL = _descriptor.Descriptor(
  name='Thumbnail',
  full_name='proto.Thumbnail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='proto.Thumbnail.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='proto.Thumbnail.width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='proto.Thumbnail.height', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_id', full_name='proto.Thumbnail.cache_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.Thumbnail.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mime', full_name='proto.Thumbnail.mime', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6243,
  serialized_end=6345,
)


_FILE = _descriptor.Descriptor(
  name='File',
  full_name='proto.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.File.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.File.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size', full_name='proto.File.size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='large_thumbnail', full_name='proto.File.large_thumbnail', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='small_thumbnail', full_name='proto.File.small_thumbnail', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='waveform_thumbnail', full_name='proto.File.waveform_thumbnail', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='proto.File.width', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='proto.File.height', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='proto.File.duration', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_id', full_name='proto.File.cache_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mime', full_name='proto.File.mime', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_url', full_name='proto.File.public_url', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6348,
  serialized_end=6630,
)


_POSTMESSAGERIGHTS = _descriptor.Descriptor(
  name='PostMessageRights',
  full_name='proto.PostMessageRights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_text', full_name='proto.PostMessageRights.send_text', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_media', full_name='proto.PostMessageRights.send_media', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_gif', full_name='proto.PostMessageRights.send_gif', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_sticker', full_name='proto.PostMessageRights.send_sticker', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_link', full_name='proto.PostMessageRights.send_link', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6632,
  serialized_end=6749,
)


_ROOMACCESS = _descriptor.Descriptor(
  name='RoomAccess',
  full_name='proto.RoomAccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modify_room', full_name='proto.RoomAccess.modify_room', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='post_message', full_name='proto.RoomAccess.post_message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edit_message', full_name='proto.RoomAccess.edit_message', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_message', full_name='proto.RoomAccess.delete_message', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_message', full_name='proto.RoomAccess.pin_message', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_member', full_name='proto.RoomAccess.add_member', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ban_member', full_name='proto.RoomAccess.ban_member', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='get_member', full_name='proto.RoomAccess.get_member', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='add_admin', full_name='proto.RoomAccess.add_admin', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6752,
  serialized_end=6979,
)


_WALLPAPER = _descriptor.Descriptor(
  name='Wallpaper',
  full_name='proto.Wallpaper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='proto.Wallpaper.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='proto.Wallpaper.color', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6981,
  serialized_end=7034,
)


_PAGINATION = _descriptor.Descriptor(
  name='Pagination',
  full_name='proto.Pagination',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='proto.Pagination.offset', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='limit', full_name='proto.Pagination.limit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7036,
  serialized_end=7079,
)


_FAVORITE = _descriptor.Descriptor(
  name='Favorite',
  full_name='proto.Favorite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.Favorite.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='textcolor', full_name='proto.Favorite.textcolor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bgcolor', full_name='proto.Favorite.bgcolor', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.Favorite.value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='proto.Favorite.image', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7081,
  serialized_end=7171,
)


_DISCOVERYFIELD = _descriptor.Descriptor(
  name='DiscoveryField',
  full_name='proto.DiscoveryField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='imageurl', full_name='proto.DiscoveryField.imageurl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.DiscoveryField.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='actiontype', full_name='proto.DiscoveryField.actiontype', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orderid', full_name='proto.DiscoveryField.orderid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.DiscoveryField.id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param', full_name='proto.DiscoveryField.param', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='agreement', full_name='proto.DiscoveryField.agreement', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='refresh', full_name='proto.DiscoveryField.refresh', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='agreementSlug', full_name='proto.DiscoveryField.agreementSlug', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DISCOVERYFIELD_BUTTONACTIONTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7174,
  serialized_end=8171,
)


_DISCOVERY = _descriptor.Descriptor(
  name='Discovery',
  full_name='proto.Discovery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='proto.Discovery.model', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scale', full_name='proto.Discovery.scale', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='discoveryfields', full_name='proto.Discovery.discoveryfields', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DISCOVERY_DISCOVERYMODEL,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8174,
  serialized_end=8449,
)


_POLLFIELD = _descriptor.Descriptor(
  name='PollField',
  full_name='proto.PollField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='imageurl', full_name='proto.PollField.imageurl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orderid', full_name='proto.PollField.orderid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='proto.PollField.id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clicked', full_name='proto.PollField.clicked', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sum', full_name='proto.PollField.sum', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clickable', full_name='proto.PollField.clickable', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label', full_name='proto.PollField.label', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8451,
  serialized_end=8573,
)


_POLL = _descriptor.Descriptor(
  name='Poll',
  full_name='proto.Poll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='proto.Poll.model', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scale', full_name='proto.Poll.scale', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max', full_name='proto.Poll.max', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pollfields', full_name='proto.Poll.pollfields', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8575,
  serialized_end=8695,
)


_IVANDACTIVITY = _descriptor.Descriptor(
  name='IVandActivity',
  full_name='proto.IVandActivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='proto.IVandActivity.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='proto.IVandActivity.score', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='proto.IVandActivity.time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8697,
  serialized_end=8756,
)


_MPLSALE = _descriptor.Descriptor(
  name='MplSale',
  full_name='proto.MplSale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invoice_number', full_name='proto.MplSale.invoice_number', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_user_id', full_name='proto.MplSale.from_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.MplSale.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trace_number', full_name='proto.MplSale.trace_number', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pay_time', full_name='proto.MplSale.pay_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.MplSale.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='card_number', full_name='proto.MplSale.card_number', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rrn', full_name='proto.MplSale.rrn', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplSale.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MPLSALE_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8759,
  serialized_end=9033,
)


_MPLTRANSACTION_BILL = _descriptor.Descriptor(
  name='Bill',
  full_name='proto.MplTransaction.Bill',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='BillId', full_name='proto.MplTransaction.Bill.BillId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='PayId', full_name='proto.MplTransaction.Bill.PayId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='BillType', full_name='proto.MplTransaction.Bill.BillType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='Status', full_name='proto.MplTransaction.Bill.Status', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='Amount', full_name='proto.MplTransaction.Bill.Amount', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='CardNumber', full_name='proto.MplTransaction.Bill.CardNumber', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='MerchantName', full_name='proto.MplTransaction.Bill.MerchantName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='OrderId', full_name='proto.MplTransaction.Bill.OrderId', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='RequestDateTime', full_name='proto.MplTransaction.Bill.RequestDateTime', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='RRN', full_name='proto.MplTransaction.Bill.RRN', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='StatusDescription', full_name='proto.MplTransaction.Bill.StatusDescription', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TerminalNo', full_name='proto.MplTransaction.Bill.TerminalNo', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TraceNo', full_name='proto.MplTransaction.Bill.TraceNo', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9332,
  serialized_end=9580,
)

_MPLTRANSACTION_TOPUP = _descriptor.Descriptor(
  name='Topup',
  full_name='proto.MplTransaction.Topup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='RequesterMobileNumber', full_name='proto.MplTransaction.Topup.RequesterMobileNumber', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ChargeMobileNumber', full_name='proto.MplTransaction.Topup.ChargeMobileNumber', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TopupType', full_name='proto.MplTransaction.Topup.TopupType', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='Status', full_name='proto.MplTransaction.Topup.Status', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='Amount', full_name='proto.MplTransaction.Topup.Amount', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='CardNumber', full_name='proto.MplTransaction.Topup.CardNumber', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='MerchantName', full_name='proto.MplTransaction.Topup.MerchantName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='OrderId', full_name='proto.MplTransaction.Topup.OrderId', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='RequestDateTime', full_name='proto.MplTransaction.Topup.RequestDateTime', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='RRN', full_name='proto.MplTransaction.Topup.RRN', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='StatusDescription', full_name='proto.MplTransaction.Topup.StatusDescription', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TerminalNo', full_name='proto.MplTransaction.Topup.TerminalNo', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TraceNo', full_name='proto.MplTransaction.Topup.TraceNo', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9583,
  serialized_end=9861,
)

_MPLTRANSACTION_SALES = _descriptor.Descriptor(
  name='Sales',
  full_name='proto.MplTransaction.Sales',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Status', full_name='proto.MplTransaction.Sales.Status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='Amount', full_name='proto.MplTransaction.Sales.Amount', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='CardNumber', full_name='proto.MplTransaction.Sales.CardNumber', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='MerchantName', full_name='proto.MplTransaction.Sales.MerchantName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='OrderId', full_name='proto.MplTransaction.Sales.OrderId', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='RequestDateTime', full_name='proto.MplTransaction.Sales.RequestDateTime', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='RRN', full_name='proto.MplTransaction.Sales.RRN', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='StatusDescription', full_name='proto.MplTransaction.Sales.StatusDescription', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TerminalNo', full_name='proto.MplTransaction.Sales.TerminalNo', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TraceNo', full_name='proto.MplTransaction.Sales.TraceNo', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9864,
  serialized_end=10064,
)

_MPLTRANSACTION_CARDTOCARD = _descriptor.Descriptor(
  name='CardToCard',
  full_name='proto.MplTransaction.CardToCard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Status', full_name='proto.MplTransaction.CardToCard.Status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='Amount', full_name='proto.MplTransaction.CardToCard.Amount', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='SourceCardNumber', full_name='proto.MplTransaction.CardToCard.SourceCardNumber', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='DestCardNumber', full_name='proto.MplTransaction.CardToCard.DestCardNumber', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='BankName', full_name='proto.MplTransaction.CardToCard.BankName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='DestBankName', full_name='proto.MplTransaction.CardToCard.DestBankName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='CardOwnerName', full_name='proto.MplTransaction.CardToCard.CardOwnerName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='OrderId', full_name='proto.MplTransaction.CardToCard.OrderId', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='RequestDateTime', full_name='proto.MplTransaction.CardToCard.RequestDateTime', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='RRN', full_name='proto.MplTransaction.CardToCard.RRN', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='StatusDescription', full_name='proto.MplTransaction.CardToCard.StatusDescription', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='TraceNo', full_name='proto.MplTransaction.CardToCard.TraceNo', index=11,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10067,
  serialized_end=10323,
)

_MPLTRANSACTION = _descriptor.Descriptor(
  name='MplTransaction',
  full_name='proto.MplTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='proto.MplTransaction.order_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.MplTransaction.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pay_time', full_name='proto.MplTransaction.pay_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.MplTransaction.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bill', full_name='proto.MplTransaction.bill', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topup', full_name='proto.MplTransaction.topup', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sales', full_name='proto.MplTransaction.sales', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cardtocard', full_name='proto.MplTransaction.cardtocard', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MPLTRANSACTION_BILL, _MPLTRANSACTION_TOPUP, _MPLTRANSACTION_SALES, _MPLTRANSACTION_CARDTOCARD, ],
  enum_types=[
    _MPLTRANSACTION_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9036,
  serialized_end=10391,
)

_ROOMMESSAGELOG_TARGETUSER.containing_type = _ROOMMESSAGELOG
_ROOMMESSAGELOG.fields_by_name['type'].enum_type = _ROOMMESSAGELOG_TYPE
_ROOMMESSAGELOG.fields_by_name['extra_type'].enum_type = _ROOMMESSAGELOG_EXTRATYPE
_ROOMMESSAGELOG.fields_by_name['target_user'].message_type = _ROOMMESSAGELOG_TARGETUSER
_ROOMMESSAGELOG_TYPE.containing_type = _ROOMMESSAGELOG
_ROOMMESSAGELOG_EXTRATYPE.containing_type = _ROOMMESSAGELOG
_ROOMMESSAGEWALLET_MONEYTRANSFER.containing_type = _ROOMMESSAGEWALLET
_ROOMMESSAGEWALLET_CARDTOCARD.containing_type = _ROOMMESSAGEWALLET
_ROOMMESSAGEWALLET_TOPUP.fields_by_name['topup_type'].enum_type = _ROOMMESSAGEWALLET_TOPUP_TYPE
_ROOMMESSAGEWALLET_TOPUP.containing_type = _ROOMMESSAGEWALLET
_ROOMMESSAGEWALLET_TOPUP_TYPE.containing_type = _ROOMMESSAGEWALLET_TOPUP
_ROOMMESSAGEWALLET_BILL.containing_type = _ROOMMESSAGEWALLET
_ROOMMESSAGEWALLET.fields_by_name['type'].enum_type = _ROOMMESSAGEWALLET_TYPE
_ROOMMESSAGEWALLET.fields_by_name['money_transfer'].message_type = _ROOMMESSAGEWALLET_MONEYTRANSFER
_ROOMMESSAGEWALLET.fields_by_name['card_to_card'].message_type = _ROOMMESSAGEWALLET_CARDTOCARD
_ROOMMESSAGEWALLET.fields_by_name['topup'].message_type = _ROOMMESSAGEWALLET_TOPUP
_ROOMMESSAGEWALLET.fields_by_name['bill'].message_type = _ROOMMESSAGEWALLET_BILL
_ROOMMESSAGEWALLET_TYPE.containing_type = _ROOMMESSAGEWALLET
_REGISTEREDUSER.fields_by_name['status'].enum_type = _REGISTEREDUSER_STATUS
_REGISTEREDUSER.fields_by_name['avatar'].message_type = _AVATAR
_REGISTEREDUSER_STATUS.containing_type = _REGISTEREDUSER
_AVATAR.fields_by_name['file'].message_type = _FILE
_ROOMMESSAGE_AUTHOR_USER.containing_type = _ROOMMESSAGE_AUTHOR
_ROOMMESSAGE_AUTHOR_ROOM.containing_type = _ROOMMESSAGE_AUTHOR
_ROOMMESSAGE_AUTHOR.fields_by_name['user'].message_type = _ROOMMESSAGE_AUTHOR_USER
_ROOMMESSAGE_AUTHOR.fields_by_name['room'].message_type = _ROOMMESSAGE_AUTHOR_ROOM
_ROOMMESSAGE_AUTHOR.containing_type = _ROOMMESSAGE
_ROOMMESSAGE_CHANNELEXTRA.containing_type = _ROOMMESSAGE
_ROOMMESSAGE.fields_by_name['status'].enum_type = _ROOMMESSAGESTATUS
_ROOMMESSAGE.fields_by_name['message_type'].enum_type = _ROOMMESSAGETYPE
_ROOMMESSAGE.fields_by_name['attachment'].message_type = _FILE
_ROOMMESSAGE.fields_by_name['author'].message_type = _ROOMMESSAGE_AUTHOR
_ROOMMESSAGE.fields_by_name['location'].message_type = _ROOMMESSAGELOCATION
_ROOMMESSAGE.fields_by_name['log'].message_type = _ROOMMESSAGELOG
_ROOMMESSAGE.fields_by_name['contact'].message_type = _ROOMMESSAGECONTACT
_ROOMMESSAGE.fields_by_name['wallet'].message_type = _ROOMMESSAGEWALLET
_ROOMMESSAGE.fields_by_name['forward_from'].message_type = _ROOMMESSAGE
_ROOMMESSAGE.fields_by_name['reply_to'].message_type = _ROOMMESSAGE
_ROOMMESSAGE.fields_by_name['extra_type'].enum_type = _ROOMMESSAGE_EXTRATYPE
_ROOMMESSAGE.fields_by_name['channel_extra'].message_type = _ROOMMESSAGE_CHANNELEXTRA
_ROOMMESSAGE_EXTRATYPE.containing_type = _ROOMMESSAGE
_ROOM.fields_by_name['type'].enum_type = _ROOM_TYPE
_ROOM.fields_by_name['last_message'].message_type = _ROOMMESSAGE
_ROOM.fields_by_name['draft'].message_type = _ROOMDRAFT
_ROOM.fields_by_name['first_unread_message'].message_type = _ROOMMESSAGE
_ROOM.fields_by_name['room_mute'].enum_type = _ROOMMUTE
_ROOM.fields_by_name['pinned_message'].message_type = _ROOMMESSAGE
_ROOM.fields_by_name['chat_room_extra'].message_type = _CHATROOM
_ROOM.fields_by_name['group_room_extra'].message_type = _GROUPROOM
_ROOM.fields_by_name['channel_room_extra'].message_type = _CHANNELROOM
_ROOM.fields_by_name['permission'].message_type = _ROOMACCESS
_ROOM_TYPE.containing_type = _ROOM
_CHATROOM.fields_by_name['peer'].message_type = _REGISTEREDUSER
_GROUPROOM_PRIVATEEXTRA.containing_type = _GROUPROOM
_GROUPROOM_PUBLICEXTRA.containing_type = _GROUPROOM
_GROUPROOM.fields_by_name['type'].enum_type = _GROUPROOM_TYPE
_GROUPROOM.fields_by_name['role'].enum_type = _GROUPROOM_ROLE
_GROUPROOM.fields_by_name['avatar'].message_type = _AVATAR
_GROUPROOM.fields_by_name['private_extra'].message_type = _GROUPROOM_PRIVATEEXTRA
_GROUPROOM.fields_by_name['public_extra'].message_type = _GROUPROOM_PUBLICEXTRA
_GROUPROOM.fields_by_name['room_rights'].message_type = GroupChangeMemberRights__pb2._GROUPCHANGEMEMBERRIGHTS_MEMBERRIGHTS
_GROUPROOM_TYPE.containing_type = _GROUPROOM
_GROUPROOM_ROLE.containing_type = _GROUPROOM
_CHANNELROOM_PRIVATEEXTRA.containing_type = _CHANNELROOM
_CHANNELROOM_PUBLICEXTRA.containing_type = _CHANNELROOM
_CHANNELROOM.fields_by_name['type'].enum_type = _CHANNELROOM_TYPE
_CHANNELROOM.fields_by_name['role'].enum_type = _CHANNELROOM_ROLE
_CHANNELROOM.fields_by_name['avatar'].message_type = _AVATAR
_CHANNELROOM.fields_by_name['private_extra'].message_type = _CHANNELROOM_PRIVATEEXTRA
_CHANNELROOM.fields_by_name['public_extra'].message_type = _CHANNELROOM_PUBLICEXTRA
_CHANNELROOM_TYPE.containing_type = _CHANNELROOM
_CHANNELROOM_ROLE.containing_type = _CHANNELROOM
_FILE.fields_by_name['large_thumbnail'].message_type = _THUMBNAIL
_FILE.fields_by_name['small_thumbnail'].message_type = _THUMBNAIL
_FILE.fields_by_name['waveform_thumbnail'].message_type = _THUMBNAIL
_ROOMACCESS.fields_by_name['post_message'].message_type = _POSTMESSAGERIGHTS
_WALLPAPER.fields_by_name['file'].message_type = _FILE
_DISCOVERYFIELD.fields_by_name['actiontype'].enum_type = _DISCOVERYFIELD_BUTTONACTIONTYPE
_DISCOVERYFIELD_BUTTONACTIONTYPE.containing_type = _DISCOVERYFIELD
_DISCOVERY.fields_by_name['model'].enum_type = _DISCOVERY_DISCOVERYMODEL
_DISCOVERY.fields_by_name['discoveryfields'].message_type = _DISCOVERYFIELD
_DISCOVERY_DISCOVERYMODEL.containing_type = _DISCOVERY
_POLL.fields_by_name['model'].enum_type = _DISCOVERY_DISCOVERYMODEL
_POLL.fields_by_name['pollfields'].message_type = _POLLFIELD
_MPLSALE.fields_by_name['status'].enum_type = _MPLSALE_STATUS
_MPLSALE_STATUS.containing_type = _MPLSALE
_MPLTRANSACTION_BILL.containing_type = _MPLTRANSACTION
_MPLTRANSACTION_TOPUP.containing_type = _MPLTRANSACTION
_MPLTRANSACTION_SALES.containing_type = _MPLTRANSACTION
_MPLTRANSACTION_CARDTOCARD.containing_type = _MPLTRANSACTION
_MPLTRANSACTION.fields_by_name['type'].enum_type = _MPLTRANSACTION_TYPE
_MPLTRANSACTION.fields_by_name['bill'].message_type = _MPLTRANSACTION_BILL
_MPLTRANSACTION.fields_by_name['topup'].message_type = _MPLTRANSACTION_TOPUP
_MPLTRANSACTION.fields_by_name['sales'].message_type = _MPLTRANSACTION_SALES
_MPLTRANSACTION.fields_by_name['cardtocard'].message_type = _MPLTRANSACTION_CARDTOCARD
_MPLTRANSACTION_TYPE.containing_type = _MPLTRANSACTION
DESCRIPTOR.message_types_by_name['RoomMessageLocation'] = _ROOMMESSAGELOCATION
DESCRIPTOR.message_types_by_name['RoomMessageLog'] = _ROOMMESSAGELOG
DESCRIPTOR.message_types_by_name['RoomMessageContact'] = _ROOMMESSAGECONTACT
DESCRIPTOR.message_types_by_name['RoomMessageWallet'] = _ROOMMESSAGEWALLET
DESCRIPTOR.message_types_by_name['RoomMessageForwardFrom'] = _ROOMMESSAGEFORWARDFROM
DESCRIPTOR.message_types_by_name['RegisteredUser'] = _REGISTEREDUSER
DESCRIPTOR.message_types_by_name['Avatar'] = _AVATAR
DESCRIPTOR.message_types_by_name['RoomMessage'] = _ROOMMESSAGE
DESCRIPTOR.message_types_by_name['RoomDraft'] = _ROOMDRAFT
DESCRIPTOR.message_types_by_name['Room'] = _ROOM
DESCRIPTOR.message_types_by_name['ChatRoom'] = _CHATROOM
DESCRIPTOR.message_types_by_name['GroupRoom'] = _GROUPROOM
DESCRIPTOR.message_types_by_name['ChannelRoom'] = _CHANNELROOM
DESCRIPTOR.message_types_by_name['Thumbnail'] = _THUMBNAIL
DESCRIPTOR.message_types_by_name['File'] = _FILE
DESCRIPTOR.message_types_by_name['PostMessageRights'] = _POSTMESSAGERIGHTS
DESCRIPTOR.message_types_by_name['RoomAccess'] = _ROOMACCESS
DESCRIPTOR.message_types_by_name['Wallpaper'] = _WALLPAPER
DESCRIPTOR.message_types_by_name['Pagination'] = _PAGINATION
DESCRIPTOR.message_types_by_name['Favorite'] = _FAVORITE
DESCRIPTOR.message_types_by_name['DiscoveryField'] = _DISCOVERYFIELD
DESCRIPTOR.message_types_by_name['Discovery'] = _DISCOVERY
DESCRIPTOR.message_types_by_name['PollField'] = _POLLFIELD
DESCRIPTOR.message_types_by_name['Poll'] = _POLL
DESCRIPTOR.message_types_by_name['IVandActivity'] = _IVANDACTIVITY
DESCRIPTOR.message_types_by_name['MplSale'] = _MPLSALE
DESCRIPTOR.message_types_by_name['MplTransaction'] = _MPLTRANSACTION
DESCRIPTOR.enum_types_by_name['Gender'] = _GENDER
DESCRIPTOR.enum_types_by_name['Device'] = _DEVICE
DESCRIPTOR.enum_types_by_name['Platform'] = _PLATFORM
DESCRIPTOR.enum_types_by_name['Language'] = _LANGUAGE
DESCRIPTOR.enum_types_by_name['RoomMessageType'] = _ROOMMESSAGETYPE
DESCRIPTOR.enum_types_by_name['RoomMessageStatus'] = _ROOMMESSAGESTATUS
DESCRIPTOR.enum_types_by_name['RoomMessageReaction'] = _ROOMMESSAGEREACTION
DESCRIPTOR.enum_types_by_name['ClientAction'] = _CLIENTACTION
DESCRIPTOR.enum_types_by_name['RoomMute'] = _ROOMMUTE
DESCRIPTOR.enum_types_by_name['PrivacyType'] = _PRIVACYTYPE
DESCRIPTOR.enum_types_by_name['PrivacyLevel'] = _PRIVACYLEVEL

RoomMessageLocation = _reflection.GeneratedProtocolMessageType('RoomMessageLocation', (_message.Message,), dict(
  DESCRIPTOR = _ROOMMESSAGELOCATION,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RoomMessageLocation)
  ))
_sym_db.RegisterMessage(RoomMessageLocation)

RoomMessageLog = _reflection.GeneratedProtocolMessageType('RoomMessageLog', (_message.Message,), dict(

  TargetUser = _reflection.GeneratedProtocolMessageType('TargetUser', (_message.Message,), dict(
    DESCRIPTOR = _ROOMMESSAGELOG_TARGETUSER,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.RoomMessageLog.TargetUser)
    ))
  ,
  DESCRIPTOR = _ROOMMESSAGELOG,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RoomMessageLog)
  ))
_sym_db.RegisterMessage(RoomMessageLog)
_sym_db.RegisterMessage(RoomMessageLog.TargetUser)

RoomMessageContact = _reflection.GeneratedProtocolMessageType('RoomMessageContact', (_message.Message,), dict(
  DESCRIPTOR = _ROOMMESSAGECONTACT,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RoomMessageContact)
  ))
_sym_db.RegisterMessage(RoomMessageContact)

RoomMessageWallet = _reflection.GeneratedProtocolMessageType('RoomMessageWallet', (_message.Message,), dict(

  MoneyTransfer = _reflection.GeneratedProtocolMessageType('MoneyTransfer', (_message.Message,), dict(
    DESCRIPTOR = _ROOMMESSAGEWALLET_MONEYTRANSFER,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.RoomMessageWallet.MoneyTransfer)
    ))
  ,

  CardToCard = _reflection.GeneratedProtocolMessageType('CardToCard', (_message.Message,), dict(
    DESCRIPTOR = _ROOMMESSAGEWALLET_CARDTOCARD,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.RoomMessageWallet.CardToCard)
    ))
  ,

  Topup = _reflection.GeneratedProtocolMessageType('Topup', (_message.Message,), dict(
    DESCRIPTOR = _ROOMMESSAGEWALLET_TOPUP,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.RoomMessageWallet.Topup)
    ))
  ,

  Bill = _reflection.GeneratedProtocolMessageType('Bill', (_message.Message,), dict(
    DESCRIPTOR = _ROOMMESSAGEWALLET_BILL,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.RoomMessageWallet.Bill)
    ))
  ,
  DESCRIPTOR = _ROOMMESSAGEWALLET,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RoomMessageWallet)
  ))
_sym_db.RegisterMessage(RoomMessageWallet)
_sym_db.RegisterMessage(RoomMessageWallet.MoneyTransfer)
_sym_db.RegisterMessage(RoomMessageWallet.CardToCard)
_sym_db.RegisterMessage(RoomMessageWallet.Topup)
_sym_db.RegisterMessage(RoomMessageWallet.Bill)

RoomMessageForwardFrom = _reflection.GeneratedProtocolMessageType('RoomMessageForwardFrom', (_message.Message,), dict(
  DESCRIPTOR = _ROOMMESSAGEFORWARDFROM,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RoomMessageForwardFrom)
  ))
_sym_db.RegisterMessage(RoomMessageForwardFrom)

RegisteredUser = _reflection.GeneratedProtocolMessageType('RegisteredUser', (_message.Message,), dict(
  DESCRIPTOR = _REGISTEREDUSER,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisteredUser)
  ))
_sym_db.RegisterMessage(RegisteredUser)

Avatar = _reflection.GeneratedProtocolMessageType('Avatar', (_message.Message,), dict(
  DESCRIPTOR = _AVATAR,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.Avatar)
  ))
_sym_db.RegisterMessage(Avatar)

RoomMessage = _reflection.GeneratedProtocolMessageType('RoomMessage', (_message.Message,), dict(

  Author = _reflection.GeneratedProtocolMessageType('Author', (_message.Message,), dict(

    User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), dict(
      DESCRIPTOR = _ROOMMESSAGE_AUTHOR_USER,
      __module__ = 'Global_pb2'
      # @@protoc_insertion_point(class_scope:proto.RoomMessage.Author.User)
      ))
    ,

    Room = _reflection.GeneratedProtocolMessageType('Room', (_message.Message,), dict(
      DESCRIPTOR = _ROOMMESSAGE_AUTHOR_ROOM,
      __module__ = 'Global_pb2'
      # @@protoc_insertion_point(class_scope:proto.RoomMessage.Author.Room)
      ))
    ,
    DESCRIPTOR = _ROOMMESSAGE_AUTHOR,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.RoomMessage.Author)
    ))
  ,

  ChannelExtra = _reflection.GeneratedProtocolMessageType('ChannelExtra', (_message.Message,), dict(
    DESCRIPTOR = _ROOMMESSAGE_CHANNELEXTRA,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.RoomMessage.ChannelExtra)
    ))
  ,
  DESCRIPTOR = _ROOMMESSAGE,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RoomMessage)
  ))
_sym_db.RegisterMessage(RoomMessage)
_sym_db.RegisterMessage(RoomMessage.Author)
_sym_db.RegisterMessage(RoomMessage.Author.User)
_sym_db.RegisterMessage(RoomMessage.Author.Room)
_sym_db.RegisterMessage(RoomMessage.ChannelExtra)

RoomDraft = _reflection.GeneratedProtocolMessageType('RoomDraft', (_message.Message,), dict(
  DESCRIPTOR = _ROOMDRAFT,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RoomDraft)
  ))
_sym_db.RegisterMessage(RoomDraft)

Room = _reflection.GeneratedProtocolMessageType('Room', (_message.Message,), dict(
  DESCRIPTOR = _ROOM,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.Room)
  ))
_sym_db.RegisterMessage(Room)

ChatRoom = _reflection.GeneratedProtocolMessageType('ChatRoom', (_message.Message,), dict(
  DESCRIPTOR = _CHATROOM,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChatRoom)
  ))
_sym_db.RegisterMessage(ChatRoom)

GroupRoom = _reflection.GeneratedProtocolMessageType('GroupRoom', (_message.Message,), dict(

  PrivateExtra = _reflection.GeneratedProtocolMessageType('PrivateExtra', (_message.Message,), dict(
    DESCRIPTOR = _GROUPROOM_PRIVATEEXTRA,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupRoom.PrivateExtra)
    ))
  ,

  PublicExtra = _reflection.GeneratedProtocolMessageType('PublicExtra', (_message.Message,), dict(
    DESCRIPTOR = _GROUPROOM_PUBLICEXTRA,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.GroupRoom.PublicExtra)
    ))
  ,
  DESCRIPTOR = _GROUPROOM,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.GroupRoom)
  ))
_sym_db.RegisterMessage(GroupRoom)
_sym_db.RegisterMessage(GroupRoom.PrivateExtra)
_sym_db.RegisterMessage(GroupRoom.PublicExtra)

ChannelRoom = _reflection.GeneratedProtocolMessageType('ChannelRoom', (_message.Message,), dict(

  PrivateExtra = _reflection.GeneratedProtocolMessageType('PrivateExtra', (_message.Message,), dict(
    DESCRIPTOR = _CHANNELROOM_PRIVATEEXTRA,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.ChannelRoom.PrivateExtra)
    ))
  ,

  PublicExtra = _reflection.GeneratedProtocolMessageType('PublicExtra', (_message.Message,), dict(
    DESCRIPTOR = _CHANNELROOM_PUBLICEXTRA,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.ChannelRoom.PublicExtra)
    ))
  ,
  DESCRIPTOR = _CHANNELROOM,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelRoom)
  ))
_sym_db.RegisterMessage(ChannelRoom)
_sym_db.RegisterMessage(ChannelRoom.PrivateExtra)
_sym_db.RegisterMessage(ChannelRoom.PublicExtra)

Thumbnail = _reflection.GeneratedProtocolMessageType('Thumbnail', (_message.Message,), dict(
  DESCRIPTOR = _THUMBNAIL,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.Thumbnail)
  ))
_sym_db.RegisterMessage(Thumbnail)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), dict(
  DESCRIPTOR = _FILE,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.File)
  ))
_sym_db.RegisterMessage(File)

PostMessageRights = _reflection.GeneratedProtocolMessageType('PostMessageRights', (_message.Message,), dict(
  DESCRIPTOR = _POSTMESSAGERIGHTS,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.PostMessageRights)
  ))
_sym_db.RegisterMessage(PostMessageRights)

RoomAccess = _reflection.GeneratedProtocolMessageType('RoomAccess', (_message.Message,), dict(
  DESCRIPTOR = _ROOMACCESS,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.RoomAccess)
  ))
_sym_db.RegisterMessage(RoomAccess)

Wallpaper = _reflection.GeneratedProtocolMessageType('Wallpaper', (_message.Message,), dict(
  DESCRIPTOR = _WALLPAPER,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.Wallpaper)
  ))
_sym_db.RegisterMessage(Wallpaper)

Pagination = _reflection.GeneratedProtocolMessageType('Pagination', (_message.Message,), dict(
  DESCRIPTOR = _PAGINATION,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.Pagination)
  ))
_sym_db.RegisterMessage(Pagination)

Favorite = _reflection.GeneratedProtocolMessageType('Favorite', (_message.Message,), dict(
  DESCRIPTOR = _FAVORITE,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.Favorite)
  ))
_sym_db.RegisterMessage(Favorite)

DiscoveryField = _reflection.GeneratedProtocolMessageType('DiscoveryField', (_message.Message,), dict(
  DESCRIPTOR = _DISCOVERYFIELD,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.DiscoveryField)
  ))
_sym_db.RegisterMessage(DiscoveryField)

Discovery = _reflection.GeneratedProtocolMessageType('Discovery', (_message.Message,), dict(
  DESCRIPTOR = _DISCOVERY,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.Discovery)
  ))
_sym_db.RegisterMessage(Discovery)

PollField = _reflection.GeneratedProtocolMessageType('PollField', (_message.Message,), dict(
  DESCRIPTOR = _POLLFIELD,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.PollField)
  ))
_sym_db.RegisterMessage(PollField)

Poll = _reflection.GeneratedProtocolMessageType('Poll', (_message.Message,), dict(
  DESCRIPTOR = _POLL,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.Poll)
  ))
_sym_db.RegisterMessage(Poll)

IVandActivity = _reflection.GeneratedProtocolMessageType('IVandActivity', (_message.Message,), dict(
  DESCRIPTOR = _IVANDACTIVITY,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.IVandActivity)
  ))
_sym_db.RegisterMessage(IVandActivity)

MplSale = _reflection.GeneratedProtocolMessageType('MplSale', (_message.Message,), dict(
  DESCRIPTOR = _MPLSALE,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplSale)
  ))
_sym_db.RegisterMessage(MplSale)

MplTransaction = _reflection.GeneratedProtocolMessageType('MplTransaction', (_message.Message,), dict(

  Bill = _reflection.GeneratedProtocolMessageType('Bill', (_message.Message,), dict(
    DESCRIPTOR = _MPLTRANSACTION_BILL,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.MplTransaction.Bill)
    ))
  ,

  Topup = _reflection.GeneratedProtocolMessageType('Topup', (_message.Message,), dict(
    DESCRIPTOR = _MPLTRANSACTION_TOPUP,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.MplTransaction.Topup)
    ))
  ,

  Sales = _reflection.GeneratedProtocolMessageType('Sales', (_message.Message,), dict(
    DESCRIPTOR = _MPLTRANSACTION_SALES,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.MplTransaction.Sales)
    ))
  ,

  CardToCard = _reflection.GeneratedProtocolMessageType('CardToCard', (_message.Message,), dict(
    DESCRIPTOR = _MPLTRANSACTION_CARDTOCARD,
    __module__ = 'Global_pb2'
    # @@protoc_insertion_point(class_scope:proto.MplTransaction.CardToCard)
    ))
  ,
  DESCRIPTOR = _MPLTRANSACTION,
  __module__ = 'Global_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplTransaction)
  ))
_sym_db.RegisterMessage(MplTransaction)
_sym_db.RegisterMessage(MplTransaction.Bill)
_sym_db.RegisterMessage(MplTransaction.Topup)
_sym_db.RegisterMessage(MplTransaction.Sales)
_sym_db.RegisterMessage(MplTransaction.CardToCard)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\013ProtoGlobal'))
# @@protoc_insertion_point(module_scope)
